# octavus-sdk

Official Python SDK for Octavus — the AI agent orchestration platform.

## 🚧 Coming Soon

This package is currently under development. 

**Note:** This is an alias for the `octavus` package. Please use `pip install octavus` instead.

## License

MIT

